summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/Math/BigRat.pm14
-rw-r--r--lib/bigrat.pm2
2 files changed, 8 insertions, 8 deletions
diff --git a/lib/bigrat.pm b/lib/bigrat.pm
index 49d1f38ff9..45dfed4069 100644
--- a/lib/bigrat.pm
+++ b/lib/bigrat.pm
@@ -155,7 +155,7 @@ __END__
=head1 NAME
-bigrat - Transparent BigNumber/BigRationale support for Perl
+bigrat - Transparent BigNumber/BigRational support for Perl
=head1 SYNOPSIS
diff --git a/lib/Math/BigRat.pm b/lib/Math/BigRat.pm
index 993c2a4ddc..2b5796f18a 100644
--- a/lib/Math/BigRat.pm
+++ b/lib/Math/BigRat.pm
@@ -9,7 +9,7 @@
# _n : numeraotr (value = _n/_d)
# _a : accuracy
# _p : precision
-# _f : flags, used by MBR to flag parts of a rationale as untouchable
+# _f : flags, used by MBR to flag parts of a rational as untouchable
package Math::BigRat;
@@ -56,7 +56,7 @@ sub isa
sub _new_from_float
{
- # turn a single float input into a rationale (like '0.1')
+ # turn a single float input into a rational (like '0.1')
my ($self,$f) = @_;
return $self->bnan() if $f->is_nan();
@@ -365,7 +365,7 @@ sub _bzero
sub badd
{
# add two rationales
# set up parameters
my ($self,$x,$y,@r) = (ref($_[0]),@_);
@@ -410,7 +410,7 @@ sub badd
sub bsub
{
# subtract two rationales
# set up parameters
my ($self,$x,$y,@r) = (ref($_[0]),@_);
@@ -454,7 +454,7 @@ sub bsub
sub bmul
{
# multiply two rationales
# set up parameters
my ($self,$x,$y,@r) = (ref($_[0]),@_);
@@ -1132,7 +1132,7 @@ __END__
=head1 NAME
-Math::BigRat - arbitrarily big rationales
+Math::BigRat - arbitrarily big rationals
=head1 SYNOPSIS
@@ -1146,7 +1146,7 @@ Math::BigRat - arbitrarily big rationales
=head1 DESCRIPTION
Math::BigRat complements Math::BigInt and Math::BigFloat by providing support
-for arbitrarily big rationales.
+for arbitrarily big rationals.
=head2 MATH LIBRARY
@@ -365,7 +365,7 @@ sub _bzero
sub badd
{
- # add two rationales
+ # add two rationals
# set up parameters
my ($self,$x,$y,@r) = (ref($_[0]),@_);
@@ -410,7 +410,7 @@ sub badd
sub bsub
{
- # subtract two rationales
+ # subtract two rationals
# set up parameters
my ($self,$x,$y,@r) = (ref($_[0]),@_);
@@ -454,7 +454,7 @@ sub bsub
sub bmul
{
- # multiply two rationales
+ # multiply two rationals
# set up parameters
my ($self,$x,$y,@r) = (ref($_[0]),@_);